#!/bin/bash

if [[ -z "$1" ]]; then
	echo "Missing argument: Company ID"
	exit 1
fi

# The following captures the output of the command group.
# Currently this will always wait 2 seconds regardless of if it has any output or not.
# The following "bash magic" happens:
#   We use process substitution twice "<(...)", this creates
#   2 temporary file descriptors which we then concatenate using cat.
#     - The printf file descriptor will simply print whatever is being printed.
#     - The sleep file descriptor won't print anything but cat will still
#       wait for it to complete.
#   We then spawn a background task by piping the output from cat to netcat.
#   Finally we simply wait 2 seconds to kill the background task.
RESULT=$(
	{
		cat <(printf "%s\r\n" "CMD apiclient \"register $1\"") <(sleep 2) | nc localhost 9240 &
		pid=$!
		sleep 2
		kill $pid 2> /dev/null
	}
)

if [[ -z "$RESULT" ]]; then
	echo "Agent isn't running"
	exit 1
fi

if [[ ${RESULT} == *"3=Already registered"* ]]; then
	echo "Agent has already been registered"
	exit 1
elif [[ ${RESULT} == *"1=Invalid parameter company ID"* ]]; then
	echo "Invalid company ID"
	exit 1
elif [[ ${RESULT} == *"110 \"apiclient\" \"registered\""* ]]; then
	echo "The agent has been registered"
	exit 0
fi

echo "Failed to register the Agent"

exit 1
